@@ -5,14 +5,12 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
     from sklearn import metrics
     
     
-    #Feature Importance
-    print('\nFeature Importance')
-    
+    #Feature Importance    
     if algo == 'mars':
-        
+        print('\nFeature Importance')
         features = pd.DataFrame()
         features['features'] = model.named_steps['earth'].xlabels_
-        features['importance'] = model.named_steps['earth'].feature_importances_
+        features['importance'] = np.round(model.named_steps['earth'].feature_importances_,4)
         features.sort_values(by=['importance'], ascending=False, inplace=True)
         display(features)
         
@@ -22,6 +20,9 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
         explainer = shap.Explainer(model)
         shap_values = explainer(x_train)
 
+        #mean absolute value of the SHAP values
+        print('\nFeature Importance')
+        shap.plots.bar(shap_values)
 
         # visualize the first prediction's explanation
         #believe this is the log-likelihood. Would need to exp()
@@ -30,9 +31,6 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
 
         # visualize the first prediction's explanation with a force plot
         shap.plots.beeswarm(shap_values)
-
-        #mean absolute value of the SHAP values
-        shap.plots.bar(shap_values)
         
     
     #TRAIN DATA: Get Predicted and Actual
@@ -62,9 +60,26 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
               ]
 
     metricx = pd.DataFrame(metricx, columns=['metric', 'train', 'test'])
+    metricx['deviation_pct'] = (metricx['test'] - metricx['train']) / metricx['train']
+    
+    print('\nModel Metrics')
+    format_dict = {'train':'{0:,.4}', 'test': '{0:.4}', 'deviation_pct': '{:.2%}'}
+    display(metricx.style.format(format_dict))
+    
+    #Determine log-loss cutpoint
+    multi=10000
+    class_ratio = [np.round(score_test['actual'].mean(),3), 1-np.round(score_test['actual'].mean(),3)]
+    
+    actuals=[]
+    for i,val in enumerate(class_ratio):
+        actuals=actuals+[i for x in range(int(val*multi))]
+        
+    preds=[]
+    for i in range(multi):
+        preds+=[class_ratio]
+
+    print(f'log-loss: values below {metrics.log_loss(actuals, preds)} are better than chance.\n\n')
     
-    print('Model Metrics')
-    display(metricx)
     
     #Classification Metrics
     if classification == 'Y':
@@ -87,11 +102,13 @@ def model_metrics(model, x_train, y_train, x_test, y_test, show_graphs='Y', f_sc
                                  ]
         
         classification_metricx = pd.DataFrame(classification_metricx, columns=['metric', 'train', 'test'])
+        classification_metricx['deviation_pct'] = (classification_metricx['test'] - classification_metricx['train']) / classification_metricx['train']
         
         print('Classification Metrics')
         print(f'Using an F-Score of {f_score}')
-        display(classification_metricx)
-                            
+        format_dict = {'train':'{0:,.4}', 'test': '{0:.4}', 'deviation_pct': '{:.2%}'}
+        display(classification_metricx.style.format(format_dict))
+        
         print('Accuracy: % of Accurate Predictions. (True Positives + True Negatives) / Total Population')
         print('Precision: % of true positives to all positives. True Positives / (True Positives + False Positives)')
         print('Recall: % of postive cases accurately classified. True Positives / (True Positives + False Negatives)')
